@@ -8,3 +8,6 @@ jquerylayout = ResourceInclusion(
     jquerylayout_lib, 'jquery.layout.js',
     depends=[jquery, jqueryui],
     minified='jquery.layout.min.js')
+
+jquerylayout_css = ResourceInclusion(
+    jquerylayout_lib, 'layout.css')
